#! /usr/bin/python
#***********************************************************
#* Software License Agreement (BSD License)
#*
#*  Copyright (c) 2009, Willow Garage, Inc.
#*  All rights reserved.
#*
#*  Redistribution and use in source and binary forms, with or without
#*  modification, are permitted provided that the following conditions
#*  are met:
#*
#*   * Redistributions of source code must retain the above copyright
#*     notice, this list of conditions and the following disclaimer.
#*   * Redistributions in binary form must reproduce the above
#*     copyright notice, this list of conditions and the following
#*     disclaimer in the documentation and/or other materials provided
#*     with the distribution.
#*   * Neither the name of Willow Garage, Inc. nor the names of its
#*     contributors may be used to endorse or promote products derived
#*     from this software without specific prior written permission.
#*
#*  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
#*  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
#*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
#*  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
#*  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
#*  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
#*  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
#*  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
#*  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
#*  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
#*  ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
#*  POSSIBILITY OF SUCH DAMAGE.
#* 
#* Author: Eitan Marder-Eppstein
#***********************************************************
import roslib; roslib.load_manifest('ui_responder')
import rospy

from std_msgs.msg import Empty

from PyQt4 import QtGui, QtCore

import sys


class UIResponder(QtGui.QWidget):
    preempted = QtCore.pyqtSignal()
    def __init__(self, parent=None):
        QtGui.QWidget.__init__(self, parent)
        self.pub = rospy.Publisher(rospy.remap_name('action_ns') + '/preempt_response', Empty)
        self.sub = rospy.Subscriber(rospy.remap_name('action_ns') + '/preempt_request', Empty, self.req_cb)
        self.preempted.connect(self.handle_preempt)

    def handle_preempt(self):
        try:
            rospy.loginfo("Displaying ui_responder popup")
            reply = QtGui.QMessageBox.question(self, 'Message',
                                               "Are you ready to preempt?", QtGui.QMessageBox.Yes, QtGui.QMessageBox.Yes)
        finally:
            rospy.loginfo("Exiting ui_responder")
            #TODO: Quit the application, and shutdown ROS
            rospy.signal_shutdown('quit')
            QtGui.qApp.quit()
            sys.exit()

    def req_cb(self, msg):
        self.preempted.emit()

def main():
    rospy.init_node('ui_responder', None, False, 2, False, False, True)
    app = QtGui.QApplication(rospy.myargv(sys.argv))
    ui_r = UIResponder()
    app.exec_()

if __name__ == '__main__':
    main()
